GeezDate class

Constructors

GeezDate(int year, int month, int date, [int hour = 1, int minute = 0, int second = 0, Shift shift = Shift.day])
const
GeezDate.fromDateTime(DateTime dateTime)
factory
GeezDate.fromJson(Map<String, int> json)
factory
GeezDate.fromString(String dateTimeString)
factory
GeezDate.now()
factory

Properties

date int
final
hashCode int
The hash code for this object.
no setteroverride
hour int
final
isFuture bool
no setter
isPast bool
no setter
isThisHour bool
no setter
isThisMinute bool
no setter
isThisMonth bool
no setter
isThisSecond bool
no setter
isThisyear bool
no setter
isToday bool
no setter
minute int
final
month int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
second int
final
shift Shift
final
year int
final

Methods

add({int years = 0, int months = 0, int weeks = 0, int days = 0, int hours = 0, int minutes = 0, int seconds = 0}) GeezDate
compareTo(GeezDate date, [CompareDatesResultUnit unit = CompareDatesResultUnit.day]) num
format(String pattern, {FormatLanguage lang = FormatLanguage.ti, FormatLength length = FormatLength.long}) String
formats
isBetween(GeezDate start, GeezDate end) bool
isSameDate(GeezDate date) bool
isSameDay(GeezDate date) bool
isSameHour(GeezDate date) bool
isSameMinute(GeezDate date) bool
isSameMonth(GeezDate date) bool
isSameSecond(GeezDate date) bool
isSameYear(GeezDate date) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subtract({int years = 0, int months = 0, int weeks = 0, int days = 0, int hours = 0, int minutes = 0, int seconds = 0}) GeezDate
toGC() DateTime
toString() String
A string representation of this object.
override

Operators

operator +(covariant int seconds) GeezDate
operator -(covariant int seconds) GeezDate
operator <(covariant GeezDate other) bool
operator <=(covariant GeezDate other) bool
operator ==(covariant GeezDate other) bool
The equality operator.
override
operator >(covariant GeezDate other) bool
operator >=(covariant GeezDate other) bool

Static Methods

formatGC(DateTime datetime, String format, {FormatLanguage lang = FormatLanguage.en, FormatLength length = FormatLength.short}) String